"use strict";
/*
 * Copyright 2018 Amazon.com, Inc. and its affiliates. All Rights Reserved.
 *
 * SPDX-License-Identifier: LicenseRef-.amazon.com.-AmznSL-1.0
 *
 * Licensed under the Amazon Software License (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *   http://aws.amazon.com/asl/
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const sinon = require("sinon");
const mockFileSystem = require("mock-fs");
const path = require("path");
const assert_1 = require("assert");
const utilities_1 = require("./utilities");
describe('vscode.updateDiagnostics', function () {
    this.timeout(5000);
    let dummyFileSystem;
    let dummyDocument;
    let dummyCollection;
    let updateDiagnostics; // Subject under test
    beforeEach(() => {
        utilities_1.mockVsCode();
        updateDiagnostics = require('../extension').updateDiagnostics;
        dummyFileSystem = JSON.parse(JSON.stringify(utilities_1.DUMMY_FILE_SYSTEM));
        mockFileSystem(dummyFileSystem);
        dummyDocument = {
            languageId: 'abc-format',
            uri: { fsPath: path.resolve(path.join(utilities_1.PROJECT_CONTENT_DIR, 'foo.abc')) },
            lineAt: sinon.stub().callsFake((lineNumber) => ({ range: `dummy-range-at-line-${lineNumber}` })),
        };
        dummyCollection = new Map();
        // @ts-ignore: Set dummy String-type keys and values
        dummyCollection.set('foo-key', 'foo-value');
    });
    afterEach(() => {
        mockFileSystem.restore();
        utilities_1.restoreVsCode();
    });
    it('clears diagnostic collection', async () => {
        await updateDiagnostics(dummyDocument, dummyCollection);
        // @ts-ignore
        assert_1.strict.equal(dummyCollection.size, 0);
    });
    describe('with import errors', () => {
        beforeEach(() => {
            delete dummyFileSystem[utilities_1.PROJECT_CONTENT_DIR]['more-content']['bar.abc'];
            mockFileSystem.restore();
            mockFileSystem(dummyFileSystem);
        });
        it('pushes import errors into diagnostic collection', async () => {
            await updateDiagnostics(dummyDocument, dummyCollection);
            assert_1.strict.deepEqual(
            // @ts-ignore
            dummyCollection.get(dummyDocument.uri), [
                {
                    code: '',
                    message: 'Cannot find the scene name=[answered no] to go to.',
                    range: 'dummy-range-at-line-11',
                    severity: 0,
                    source: '',
                    relatedInformation: [],
                },
            ]);
        });
    });
    describe('when document is empty', () => {
        beforeEach(() => {
            dummyDocument = null;
        });
        it('clears diagnostic collection', async () => {
            await updateDiagnostics(dummyDocument, dummyCollection);
            // @ts-ignore
            assert_1.strict.equal(dummyCollection.size, 0);
        });
    });
    describe('when document is not sfb-format', () => {
        beforeEach(() => {
            dummyDocument = { languageId: 'some-other-language' };
        });
        it('clears diagnostic collection', async () => {
            await updateDiagnostics(dummyDocument, dummyCollection);
            // @ts-ignore
            assert_1.strict.equal(dummyCollection.size, 0);
        });
    });
});
//# sourceMappingURL=updateDiagnostics.spec.js.map